"""
Библиотека для просмотра кода по ячейкам

from rci import RCI

rci = RCI()
print(rci.get_imports())  # Должен вывести общий импорт
print(rci.get_cell(1, 1, 0))  # Должен вывести первую ячейку первой задачи

help(rci.get_imports)
help(rci.get_cell)

"""

from .core import RCI



import importlib.resources

class RCI:
    def __init__(self):
        self.text = self._load_data()
    
    def _load_data(self):
        with importlib.resources.open_text("rci_gg.data", "all_DL.txt") as file:
            return file.read()
    
    def get_imports(self):
        """
        print(get_imports()) - получить общий импорт для всех заданий
        """
        return self.text.split("###")[0]
    
    def get_cell(self, topic, task, cell):
        """
        topic:
        1 - regression
        2 - classification
        3 - images
        
        task:
        1.
        1 - 2. Набор данных: regression/gold.csv. Оптимизаторы
        2 - 2. Набор данных: regression/gold.csv. Гиперпараметры
        3 - 2. Набор данных: regression/bike_cnt.csv. BatchNorm1d
        4 - 2. Набор данных: regression/bike_cnt.csv. Dropout
        
        2.
        1 - 2. Набор данных: classification/bank.csv. Оптимизаторы
        2 - 2. Набор данных: classification/bank.csv. Dropout
        3 - 2. Набор данных: classification/bank.csv. Несбалансированность
        
        3.
        1 - 3. Набор данных: images/sign_language.zip. Скрытые представления
        2 - 3. Набор данных: images/sign_language.zip. PCA
        3 - 3. Набор данных: images/sign_language.zip. Число сверточных блоков
        4 - 3. Набор данных: images/eng_handwritten.zip. val, ранняя остановка
        5 - 3. Набор данных: images/eng_handwritten.zip. 3 модификации изображения
        6 - 3. Набор данных: images/chars.zip. Обычный и расширенный датасеты
        7 - 3. Набор данных: images/chars.zip. Неопределенные классы
        8 - 3. Набор данных: images/clothes_multi.zip. Задача множественной классификации
        
        cell:
        Номер нужной ячейки
        
        Вывод: print(get_cell(topic, task, cell))
        """
        if len(self.text.split('###')[topic].split('##')[task].split('---')) <= cell:
            return 'end'
        else:
            return self.text.split('###')[topic].split('##')[task].split('---')[cell]



from setuptools import setup, find_packages

setup(
    name="rci_gg",  # Название библиотеки
    version="0.1.2",  # Версия
    packages=find_packages(),
    include_package_data=True,  # Включаем package_data
    package_data={"rci_gg": ["data/all_DL.txt"]},  # Указываем файлы данных
    install_requires=[],  # Укажи зависимости, если есть
    description="RCI - модуль для работы с ячейками кода",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
